function [r, p, f, e] = residued(b, a, toler)

%RESIDUED Alternate partial fraction expansion
%[R,P,K,E]=RESIDUED(B,A,TOL) is similar to RESIDUEZ but for NB>=NA
%   it produces an alternate expansion where the partial fractions are
%   delayed, that is, their response comes after the direct terms (FIR
%   part).
%
%   For the details, see:
%
%   Balazs Bank and Julius O. Smith, III, "A delayed parallel filter structure
%   with an FIR part having improved numerical properties", 136th AES
%   Convention, Preprint No. 9084, Berlin, April 2014.
%
%   https://ccrma.stanford.edu/~jos/filters/FIR_Part_PFE.html
%   http://www.mit.bme.hu/~bank/delparf
%   
%   C. Julius O. Smith, 2014.

if nargin<3, toler=0.001; end
NUM = b(:)';
DEN = a(:)';
nb = length(NUM);
na = length(DEN);
f = [];
if na<=nb
  f = filter(NUM,DEN,[1 zeros(1,nb-na)]);
  NUM = NUM - conv(DEN,f);
  NUM = NUM(nb-na+2:end);
end;
[r,p,f2] = residuez(NUM,DEN);

